@@ -16,6 +16,8 @@
 // Modification History (most recent first)
 // mm/dd/yy  Who  What
 //
+// 10/17/11  VPL  Added verbose parameter
+// 10/17/11  VPL  Add optional haveNumSlices to constructor
 // 08/15/06  VPL  GPL'ed it
 // 03/22/05  VPL  Allow processing of multiple series
 //                Add NYU License agreement
@@ -41,7 +43,7 @@ std::string &DeSpace(std::string &strng);
 class DICOMImage
 {
 public:
-	DICOMImage(const char *path);
+	DICOMImage(const char *path, bool verbose = false, bool haveNumSlices = true);
 	
 	void AdjustSet(int numSlices, int imgDiff)
     {
@@ -68,6 +70,9 @@ public:
 	std::string &SeriesID()    		{ return seriesID_; }
 	int FrequencyDim() const        { return (phaseEncoding_ == 2 ? 1 : 2); }
 	int PhaseDim() const            { return phaseEncoding_; }
+	float ImgRescaleSlope() const   { return slope_; }
+	float ImgRescaleIntercept() const { return intercept_; }
+	
 	std::string &SeriesDescription(){ return seriesDescription_; }
 	std::string &SeriesNumber()     { return seriesNumber_; }
 	std::string &SeriesDate()       { return seriesDate_; }
@@ -101,7 +106,8 @@ public:
 private:
 
 	bool error_;
-
+	bool verbose_;
+	
 	bool OpenFile(const char *path);
 	
 	bool GetImageNumber();
@@ -124,6 +130,8 @@ private:
 	bool GetImgOrientation();
 	bool GetSeriesID();
 	bool GetPhaseEncoding();
+	bool GetImgRescaleIntercept();
+	bool GetImgRescaleSlope();
 	bool GetManufacturer();
 	bool GetSeriesDescription();
 	bool GetACQDescription();
@@ -159,6 +167,8 @@ private:
 	float yFOV_;
 	int repTime_;
 	int phaseEncoding_;
+	float intercept_;
+	float slope_;
 	unsigned short *volumeData_;
 	std::string seriesID_;
 	std::string seriesDescription_;
