@@ -14,6 +14,8 @@
 // Modification History (most recent first)
 // mm/dd/yy  Who  What
 //
+// 10/17/11  VPL  Add verbose parameter
+// 10/17/11  VPL  Add optional haveNumSlices to constructor
 // 03/22/05  VPL  Allow processing of multiple series
 //                Add NYU License agreement
 // 03/15/05  VPL  Adjust some items after the fact if not mosaic
@@ -58,37 +60,43 @@ string &DeSpace(string &strng)
 /// Purpose: Xctor for DICOMImage class
 ///   
 /// @param   path - path to the image
+///          verbose - show all messages
+///          haveNumSlices - don't need to read the number of slices from file ?
 ///   
 /// Notes: 
 ///
 //////////////////////////////////////////////////////////////////////////////
 
-DICOMImage::DICOMImage(const char *path) : error_(false),
-										   handle_(NULL),
-										   imageNum_(0),
-										   numGroups_(1),
-										   mosaic_(false),
-										   d3_(false),
-										   sliceThickness_(0.0),
-										   sliceSpacing_(0.0),
-										   acqNum_(0),
-										   acqEchoNum_(0),
-										   columns_(-1),
-										   rows_(-1),
-										   xFOV_(-1),
-										   yFOV_(-1),
-										   repTime_(0),
-										   phaseEncoding_(0),
-										   volumeData_(NULL),
-										   manufacturer_(UNDEFINED),
-										   shadowSet_(NULL),
-										   numSlices_(0)
+DICOMImage::DICOMImage(const char *path, bool verbose, bool haveNumSlices) :
+	error_(false),
+	handle_(NULL),
+	imageNum_(0),
+	numGroups_(1),
+	mosaic_(false),
+	d3_(false),
+	sliceThickness_(0.0),
+	sliceSpacing_(0.0),
+	acqNum_(0),
+	acqEchoNum_(0),
+	columns_(-1),
+	rows_(-1),
+	xFOV_(-1),
+	yFOV_(-1),
+	repTime_(0),
+	phaseEncoding_(0),
+	intercept_(0.),
+	slope_(0.),
+	volumeData_(NULL),
+	manufacturer_(UNDEFINED),
+	shadowSet_(NULL),
+	verbose_(verbose),
+	numSlices_(0)
 {
 	if ( ! OpenFile(path) )
 	{
 		error_ = true;
 		string msg = string("DICOMImage::DICOMImage: Cannot open file: ") + string(path);
-		cerr << endl << "\t**** " << msg << endl << endl;
+		cerr << endl << "\t**** " << msg << endl;
 	}
 	else
 	{
@@ -103,7 +111,7 @@ DICOMImage::DICOMImage(const char *path) : error_(false),
 			&& GetACQEchoNumber()
 			&& GetD3()
 			&& GetSliceThickness()
-			&& GetNumSlices()
+			&& (haveNumSlices || GetNumSlices())
 			&& GetImgOrientation()
 			&& GetFOV()
 			&& GetColumns()
@@ -114,6 +122,8 @@ DICOMImage::DICOMImage(const char *path) : error_(false),
 			&& GetComments()
 			&& GetRepetitionTime()
 			&& GetPhaseEncoding()
+			&& GetImgRescaleIntercept()
+			&& GetImgRescaleSlope()
 			&& GetNumGroups()
 			&& GetSeriesDescription()
 			&& GetSeriesNumber()
@@ -214,7 +224,7 @@ bool DICOMImage::GetManufacturer()
    {
 	  string msg("DICOMImage::GetManufacturer: Cannot get value of manufacturer in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (data != NULL) delete [] data;
 	  return false;
@@ -252,7 +262,7 @@ bool DICOMImage::GetRepetitionTime()
    {
 	  string msg("DICOMImage::GetRepetitonTime: Cannot get value of acquisition repetition time in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (data != NULL) delete [] data;
 	  return false;
@@ -286,7 +296,7 @@ bool DICOMImage::GetPhaseEncoding()
    {
 	  string msg("DICOMImage::GetPhaseEncoding: Cannot get value of phase encoding direction time in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (data != NULL) delete [] data;
 	  return false;
@@ -301,6 +311,77 @@ bool DICOMImage::GetPhaseEncoding()
    return true;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+///
+/// Purpose: Get the value for the image rescale intercept (0028,1052)
+///   
+/// @param   NONE
+///   
+/// @return  false if error
+///   
+/// Notes: This is an optional parameter. If not present, it will be set
+///        to 0 and the return is always true.
+///
+//////////////////////////////////////////////////////////////////////////////
+
+bool DICOMImage::GetImgRescaleIntercept()
+{
+   // The number is really stored as a string
+  
+   char *data = NULL;
+  
+   if (GetData(DCM_IMGRESCALEINTERCEPT, &data) == 0)
+   {
+          string msg("DICOMImage::GetImgRescaleIntercept: image ");
+          msg += imgPath_;
+		  msg += "does not contain image rescale intercept parameter, intercept set to 0";
+          if ( verbose_ ) cerr << endl << "\t**** " << msg << endl;
+          error_ = false;
+		  intercept_ = 0.;
+   }
+   else
+	   intercept_ = atof(data);
+
+   if (data != NULL) delete [] data;
+   return true;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+///
+/// Purpose: Get the value for the image rescale slope (0028,1053)
+///   
+/// @param   NONE
+///   
+/// @return  false if error
+///   
+/// Notes: This is an optional parameter. If not present, it will be set
+///        to 0 and the return is always true.
+///
+//////////////////////////////////////////////////////////////////////////////
+
+bool DICOMImage::GetImgRescaleSlope()
+{
+   // The number is really stored as a string
+  
+   char *data = NULL;
+  
+   if (GetData(DCM_IMGRESCALESLOPE, &data) == 0)
+   {
+	   string msg("DICOMImage::GetImgRescaleSlope: image ");
+          msg += imgPath_;
+		  msg += "does not contain image rescale slope parameter, slope set to 0";
+          if ( verbose_ ) cerr << endl << "\t**** " << msg << endl;
+          error_ = false;
+		  COND_PopCondition(TRUE);				// Clear error from stack
+		  slope_ = 0.;
+   }
+   else
+	   slope_ = atof(data);
+
+   if (data != NULL) delete [] data;
+   return true;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 ///
 /// Purpose: Get the value for the series instance id (0020, 000e)
@@ -321,7 +402,7 @@ bool DICOMImage::GetSeriesID()
    {
 	  string msg("DICOMImage::GetSeriesID: Cannot get value of series id in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (strn != NULL) delete [] strn;
 	  return false;
@@ -703,7 +784,7 @@ bool DICOMImage::GetImageNumber()
    {
 	  string msg("DICOMImage::ImageNumber: Cannot get value of image number in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (strn != NULL) delete [] strn;
 	  return false;
@@ -738,7 +819,7 @@ bool DICOMImage::GetSeriesNumber()
    {
 	  string msg("DICOMImage::SeriesNumber: Cannot get value of image number in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (strn != NULL) delete [] strn;
 	  return false;
@@ -773,7 +854,7 @@ bool DICOMImage::GetACQNumber()
    {
 	  string msg("DICOMImage::GetACQNumber: Cannot get value of image number in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (strn != NULL) delete [] strn;
 	  return false;
@@ -843,7 +924,7 @@ bool DICOMImage::GetImgOrientation()
 	{
 		string msg("DICOMImage::GetImgOrientation: Cannot get value of patient orientation in image ");
 		msg += imgPath_;
-		cerr << endl << "\t**** " << msg << endl << endl;
+		cerr << endl << "\t**** " << msg << endl;
 		error_ = true;
 		if (strn != NULL) delete [] strn;
 		return false;
@@ -894,7 +975,7 @@ bool DICOMImage::GetMosaic()
    {
 	  string msg("DICOMImage::Mosaic: Cannot get value of image type in image ");
 	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl << endl;
+	  cerr << endl << "\t**** " << msg << endl;
 	  error_ = true;
 	  if (strn != NULL) delete [] strn;
 	  return false;
@@ -1274,7 +1355,7 @@ bool DICOMImage::GetNumGroups()
 	{
 		string msg("DICOMImage::NumGroups: Cannot get value of Siemens info in image ");
 		msg += imgPath_;
-		cerr << endl << "\t**** " << msg << endl << endl;
+		cerr << endl << "\t**** " << msg << endl;
 		error_ = true;
 		delete [] storage;
 		storage = NULL;
@@ -1375,7 +1456,7 @@ bool DICOMImage::GetNumSlices()
 		string msg("DICOMImage::NumSlices: Cannot get number of slices from ");
 		msg += imgPath_;
 		cerr << endl << "\t**** " << msg << endl
-			 << "\t**** Setting value to 1 (can be changed with '-s' option on command line.)" << endl << endl;
+			 << "\t**** Setting value to 1 (can be changed with '-s' option on command line.)" << endl;
 	}
 
 	return true;
@@ -1600,7 +1681,7 @@ U32 DICOMImage::GetData(DCM_TAG tag, char **storage)
 	if (newLen > len)
 	{
 		string msg("DICOMImage::GetData: Inconsistent data size");
-		cerr << endl << "\t**** " << msg << endl << endl;
+		cerr << endl << "\t**** " << msg << endl;
 		error_ = true;
 		return 0;
 	}
@@ -1713,7 +1794,7 @@ bool DICOMImage::ReadSlice(U16 *data, int slice)
 	{
 		error_ = true;
 		string msg = string("DICOMImage::ReadSlice: Trying to read past end of file: ") + imgPath_;
-		cerr << endl << "\t**** " << msg << endl << endl;
+		cerr << endl << "\t**** " << msg << endl;
 		return false;
 	}
 
@@ -1768,7 +1849,7 @@ bool DICOMImage::ReadVolume()
 		{
 			error_ = true;
 			string msg = string("DICOMImage::ReadVolume: Cannot open file: ") + imgPath_;
-			cerr << endl << "\t**** " << msg << endl << endl;
+			cerr << endl << "\t**** " << msg << endl;
 			return false;
 		}
 	}		
@@ -1778,7 +1859,7 @@ bool DICOMImage::ReadVolume()
 	{
 		error_ = true;
 		string msg = string("DICOMImage::ReadVolumes: Error reading file: ") + imgPath_;
-		cerr << endl << "\t**** " << msg << endl << endl;
+		cerr << endl << "\t**** " << msg << endl;
 		return false;
 	}
 
@@ -1794,7 +1875,7 @@ bool DICOMImage::ReadVolume()
 	{
 		error_ = true;
 		string msg = string("DICOMImage::ReadVolume: Error reading file: ") + imgPath_;
-		cerr << endl << "\t**** " << msg << endl << endl;
+		cerr << endl << "\t**** " << msg << endl;
 
 		delete [] volumeData_;
 		volumeData_ = NULL;
