@@ -1,4 +1,4 @@
-#define VERSION "2.29.1"
+#define VERSION "2.30.0"
 
 //****************************************************************************
 //
@@ -410,7 +410,7 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 		string dcmFile(dicomFiles.back());
 		dicomFiles.pop_back();
 
-		DICOMImage *dcmImg = new DICOMImage(dcmFile.c_str());
+		DICOMImage *dcmImg = new DICOMImage(dcmFile.c_str(), opts.verbose, (opts.numSlices > 0));
 		if (*dcmImg)
 		{
 			SeriesInfo si = seriesMap[dcmImg->SeriesID()];
